@@ -52,7 +52,6 @@ class PGG_diffusion:
         self._nb_coop = collections.deque(maxlen=maxlen_queue)
         self._nb_def = collections.deque(maxlen=maxlen_queue)
         self._infected_node = 1
-        self._time_stamp = 0
         self._simulation_time = 0
         self.reset_send_update()
         for nd in self._G.nodes_iter():
@@ -193,7 +192,7 @@ class PGG_diffusion:
     def set_time_stamps(self, time_stamps):
         for (key, val) in time_stamps.iteritems():
             self._G.node[key]['time_stamp'] = val
-            self._time_stamp = max(val, self._time_stamp)
+            self._time_stamp = max(val, self._simulation_time)
 
     def set_nodes_states(self, nodes_states):
         for (key, val) in nodes_states.iteritems():
